@@ -8,7 +8,7 @@ from myterial import (
     green,
     indigo_lighter,
     red,
-    red_dark,
+    red_light,
     teal_light,
     teal_lighter,
 )
@@ -18,18 +18,17 @@ from myterial import (
     Colors used to highlight string expressions
     for nice printing with Rich.
 """
-unicode = teal_lighter
+
+equal = red
+operator = red_light
+operator_dark = blue_light
+number = teal_light
+parenthesis = blue
 text = indigo_lighter
 text_accent = indigo_light
-variable = orange
-number = teal_light
-operator = red_dark
-operator_dark = blue_light
-parenthesis = blue
-equal = red
 solution = pink
 result = pink
-
-
 result_panel = green
 result_panel_footer = green_dark
+unicode = teal_lighter
+variable = orange
